import React, { useState } from 'react';
import { BrowserRouter as Router, Route, Routes, Navigate, Outlet } from 'react-router-dom';
import LoginPage from './pages/LoginPage';
import Navbar from './components/Navbar';
import Sidebar from './components/Sidebar';
import AdminRoutes from './roles/AdminRoutes';
import DistributorRoutes from './roles/DistributorRoutes';
import RetailerRoutes from './roles/RetailerRoutes';
import CustomerRoutes from './roles/CustomerRoutes';

const ProtectedLayout = ({ user, onLogout }) => (
  <div className="flex h-screen bg-gray-100">
    <Sidebar user={user} onLogout={onLogout} />
    <div className="flex-1 flex flex-col overflow-hidden">
      <Navbar user={user} onLogout={onLogout} />
      <main className="flex-1 overflow-x-hidden overflow-y-auto bg-gray-200 p-4">
        <Outlet />
      </main>
    </div>
  </div>
);

const App = () => {
  const [user, setUser] = useState(null);

  const handleLogin = (userData) => setUser(userData);
  const handleLogout = () => setUser(null);

  return (
    <Router>
      <Routes>
        <Route path="/login" element={!user ? <LoginPage onLogin={handleLogin} /> : <Navigate to="/" />} />
        
        {user && (
          <Route element={<ProtectedLayout user={user} onLogout={handleLogout} />}>
            <Route path="/admin/*" element={user.role === 'admin' ? <AdminRoutes /> : <Navigate to="/" />} />
            <Route path="/distributor/*" element={user.role === 'distributor' ? <DistributorRoutes /> : <Navigate to="/" />} />
            <Route path="/retailer/*" element={user.role === 'retailer' ? <RetailerRoutes /> : <Navigate to="/" />} />
            <Route path="/customer/*" element={user.role === 'customer' ? <CustomerRoutes /> : <Navigate to="/" />} />
            <Route path="/" element={<Navigate to={`/${user.role}`} />} />
          </Route>
        )}
        
        <Route path="*" element={<Navigate to={user ? "/" : "/login"} />} />
      </Routes>
    </Router>
  );
};

export default App;