import React from 'react';
import './DashboardStyles.css';

const MarketAnalysisPage = () => {
  const competitors = [
    { id: 1, name: 'Rakip A', marketShare: '32%', growth: '+4%', rating: 4.2 },
    { id: 2, name: 'Rakip B', marketShare: '28%', growth: '+2%', rating: 3.8 },
    { id: 3, name: 'Rakip C', marketShare: '18%', growth: '-1%', rating: 3.5 },
    { id: 4, name: 'Rakip D', marketShare: '12%', growth: '+1%', rating: 3.2 },
  ];

  return (
    <div className="dashboard-page">
      <h2 className="page-title">Pazar Analiz Paneli</h2>
      
      <div className="market-overview">
        <div className="market-card">
          <h3>Pazar Payımız</h3>
          <p className="market-value">10%</p>
          <p className="market-change positive">+3% geçen yıla göre</p>
        </div>
        <div className="market-card">
          <h3>Yıllık Büyüme</h3>
          <p className="market-value">25%</p>
          <p className="market-change positive">Sektör ort: 8%</p>
        </div>
        <div className="market-card">
          <h3>Müşteri Memnuniyeti</h3>
          <p className="market-value">4.5/5</p>
          <p className="market-change positive">Sektör ort: 3.7</p>
        </div>
      </div>
      
      <div className="chart-container">
        <h3>Pazar Payı Dağılımı</h3>
        <div className="placeholder-chart">
          {/* Buraya gerçek bir pie chart component'i eklenebilir */}
          <p>Pasta grafik alanı</p>
        </div>
      </div>
      
      <div className="table-container">
        <h3>Rakip Analizi</h3>
        <table className="data-table">
          <thead>
            <tr>
              <th>Rakip Adı</th>
              <th>Pazar Payı</th>
              <th>Büyüme</th>
              <th>Puan</th>
              <th>Karşılaştırma</th>
            </tr>
          </thead>
          <tbody>
            {competitors.map(competitor => (
              <tr key={competitor.id}>
                <td>{competitor.name}</td>
                <td>{competitor.marketShare}</td>
                <td className={competitor.growth.startsWith('+') ? 'positive' : 'negative'}>
                  {competitor.growth}
                </td>
                <td>
                  <div className="rating-stars">
                    {'★'.repeat(Math.floor(competitor.rating))}
                    {'☆'.repeat(5 - Math.floor(competitor.rating))}
                    <span className="rating-value">({competitor.rating})</span>
                  </div>
                </td>
                <td>
                  <button className="action-btn compare">Karşılaştır</button>
                </td>
              </tr>
            ))}
          </tbody>
        </table>
      </div>
      
      <div className="market-insights">
        <h3>Pazar Öngörüleri</h3>
        <div className="insight-card">
          <p>Son 3 ayda müşteri taleplerinde %15 artış gözlemlendi.</p>
        </div>
        <div className="insight-card">
          <p>Rakip firmaların fiyat indirimine gitmesi pazar payımızı etkileyebilir.</p>
        </div>
      </div>
    </div>
  );
};

export default MarketAnalysisPage;